import json
from pathlib import Path
from importlib.metadata import version
from datetime import datetime

"""
This script updates the version and date metadata in all JSON files 
found within the './src/thd_json' directory and its subdirectories.

It performs the following:
1. Reads each JSON file.
2. Updates the "version" field with the version of the installed 'thd_json' package.
3. Updates the "date" field with the current date formatted as DD.MM.YYYY.
4. Writes the updated JSON data back to the file.

Usage:
- Ensure the 'thd_json' package is installed in your environment.
- Run the script, and it will process all JSON files within the specified directory.

Dependencies:
- json: To handle JSON data.
- pathlib.Path: For traversing the file system.
- importlib.metadata.version: To retrieve the version of the 'thd_json' package.
- datetime: To get and format the current date.

"""


def change_version(file_path: Path):
    with open(file_path, "r") as f:
        schema_dict = json.load(f)
    current_datetime = datetime.now()

    formatted_date = current_datetime.strftime("%d.%m.%Y")
    schema_dict["version"] = version("thd_json")
    schema_dict["date"] = formatted_date

    with open(file_path, "w") as f:
        json.dump(schema_dict, f, indent=2)


def main():
    for file in Path("./src/thd_json").rglob("*.json"):
        change_version(file)
    print(version("thd_json"))


if __name__ == "__main__":
    main()
